summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNikos <nmav@crystal.(none)>2008-02-21 19:30:46 +0200
committerNikos <nmav@crystal.(none)>2008-02-21 19:30:46 +0200
commitafd16be72f56438e89e6529512ce26d01f3c47ca (patch)
treecf1297db50242f15294964d4211eb8bc8b0eda6d
parente57a6c4c10a3265d7df41ffb52462fbf4dfe42c0 (diff)
downloadgnutls-afd16be72f56438e89e6529512ce26d01f3c47ca.tar.gz
_export_ -> _get_
-rw-r--r--lib/gnutls_cert.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/gnutls_cert.c b/lib/gnutls_cert.c
index a4f7f45615..17c47840a5 100644
--- a/lib/gnutls_cert.c
+++ b/lib/gnutls_cert.c
@@ -115,17 +115,17 @@ gnutls_certificate_free_cas (gnutls_certificate_credentials_t sc)
}
/**
* gnutls_certificate_export_x509_cas - Used to export all the CAs from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.
- * @x509_ca_list: the exported CA list. Should be treated as constant
- * @ncas: the number of exported CAs
+ * @x509_ca_list: will point to the CA list. Should be treated as constant
+ * @ncas: the number of CAs
*
* This function will export all the CAs associated
* with the given credentials.
*
**/
void
-gnutls_certificate_export_x509_cas (gnutls_certificate_credentials_t sc,
+gnutls_certificate_get_x509_cas (gnutls_certificate_credentials_t sc,
gnutls_x509_crt_t **x509_ca_list, unsigned int* ncas)
{
*x509_ca_list = sc->x509_ca_list;
@@ -133,16 +133,17 @@ gnutls_certificate_export_x509_cas (gnutls_certificate_credentials_t sc,
}
/**
* gnutls_certificate_export_x509_crls - Used to export all the CRLs from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.
- * @ring: the exported keyring. Should be treated as constant
+ * @x509_crl_list: the exported CRL list. Should be treated as constant
+ * @ncrls: the number of exported CRLs
*
* This function will export the OpenPGP keyring associated
* with the given credentials.
*
**/
void
-gnutls_certificate_export_x509_crls (gnutls_certificate_credentials_t sc,
+gnutls_certificate_get_x509_crls (gnutls_certificate_credentials_t sc,
gnutls_x509_crl_t **x509_crl_list, unsigned int* ncrls)
{
*x509_crl_list = sc->x509_crl_list;
@@ -152,17 +153,16 @@ gnutls_certificate_export_x509_crls (gnutls_certificate_credentials_t sc,
#ifdef ENABLE_OPENPGP
/**
* gnutls_certificate_export_openpgp_keyring - Used to export the keyring from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.
- * @x509_crl_list: the exported CRL list. Should be treated as constant
- * @ncrls: the number of exported CRLs
+ * @ring: the exported keyring. Should be treated as constant
*
* This function will export all the CRLs associated
* with the given credentials.
*
**/
void
-gnutls_certificate_export_openpgp_keyring (gnutls_certificate_credentials_t sc,
+gnutls_certificate_get_openpgp_keyring (gnutls_certificate_credentials_t sc,
gnutls_openpgp_keyring_t *keyring)
{
*keyring = sc->keyring;
@@ -115,17 +115,17 @@ gnutls_certificate_free_cas (gnutls_certificate_credentials_t sc)
}
/**
- * gnutls_certificate_export_x509_cas - Used to export all the CAs from a gnutls_certificate_credentials_t structure
+ * gnutls_certificate_get_x509_cas - Used to export all the CAs from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.
@@ -133,16 +133,17 @@ gnutls_certificate_export_x509_cas (gnutls_certificate_credentials_t sc,
}
/**
- * gnutls_certificate_export_x509_crls - Used to export all the CRLs from a gnutls_certificate_credentials_t structure
+ * gnutls_certificate_get_x509_crls - Used to export all the CRLs from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.
@@ -152,17 +153,16 @@ gnutls_certificate_export_x509_crls (gnutls_certificate_credentials_t sc,
#ifdef ENABLE_OPENPGP
/**
- * gnutls_certificate_export_openpgp_keyring - Used to export the keyring from a gnutls_certificate_credentials_t structure
+ * gnutls_certificate_get_openpgp_keyring - Used to export the keyring from a gnutls_certificate_credentials_t structure
* @sc: is an #gnutls_certificate_credentials_t structure.